@@ -1,7 +1,7 @@
 # Suppress R CMD check notes for NSE variables used in dplyr/ggplot2
 utils::globalVariables(c(
   "h3_address", "LST_mean", "LST_diff", "Green_Pct", "Built_Pct",
-  "Hotspot_Category", "resid_g", "x_mid", "slope", "highway"
+  "Hotspot_Category", "resid_g", "x_mid", "slope", "slope_clipped", "highway"
 ))
 
 #' Urban Heat Island Analysis & Visualization
@@ -43,7 +43,7 @@ utils::globalVariables(c(
 #' @param date_range Character vector of length 2. Date range for satellite imagery
 #'        in ISO format, e.g., c("2023-06-01", "2023-08-31"). Summer months recommended
 #'        for UHI analysis.
-#' @param hex_resolution Integer. H3 hexagon resolution (default 10, approx 65m edge length).
+#' @param hex_resolution Integer. H3 hexagon resolution (default 9).
 #'        Higher values = smaller hexagons. Range: 0-15.
 #' @param ghsl_path Character or NULL. Path to GHSL Built-S raster (.tif) for built-up
 #'        coverage. If NULL (default), uses OSM buildings as fallback.
@@ -143,7 +143,7 @@ utils::globalVariables(c(
 analyze_and_visualize_uhi <- function(
     location,
     date_range = c("2023-06-01", "2023-08-31"),
-    hex_resolution = 10,
+    hex_resolution = 9,
     ghsl_path = NULL,
     tree_canopy_radius = 5,
     thermal_source = c("auto", "ecostress", "landsat"),
@@ -201,11 +201,15 @@ analyze_and_visualize_uhi <- function(
     message("   -> Using provided bounding box")
     bbox_vec <- c(left = location[1], bottom = location[2],
                   right = location[3], top = location[4])
-    city_boundary_sf <- sf::st_as_sfc(sf::st_bbox(
-      c(xmin = bbox_vec["left"], ymin = bbox_vec["bottom"],
-        xmax = bbox_vec["right"], ymax = bbox_vec["top"]),
-      crs = 4326
-    )) %>% sf::st_as_sf()
+
+    # Create bbox object with explicit numeric values (no names in st_bbox)
+    bbox_obj <- sf::st_bbox(
+      c(xmin = unname(location[1]), ymin = unname(location[2]),
+        xmax = unname(location[3]), ymax = unname(location[4])),
+      crs = sf::st_crs(4326)
+    )
+    city_boundary_sf <- sf::st_as_sfc(bbox_obj) %>% sf::st_as_sf()
+
     location_name <- sprintf("bbox(%.2f,%.2f,%.2f,%.2f)",
                              bbox_vec["left"], bbox_vec["bottom"],
                              bbox_vec["right"], bbox_vec["top"])
@@ -1406,17 +1410,19 @@ analyze_and_visualize_uhi <- function(
     sprintf("n = %d\nr = %.2f\nAdj R^2 = %.2f\np = %.3g", n, r, adjR2, p)
   }
 
-  # top-left panel annotation (plot-relative coords)
-  annot_top <- function(label) {
+  # Annotation with background box - positioned at top-right to avoid data
+  annot_stats <- function(label) {
     ggplot2::annotate(
-      "text", x = -Inf, y = Inf, label = label,
-      hjust = -0.1, vjust = 1.1, size = 3.2, lineheight = 1.1
+      "label", x = Inf, y = Inf, label = label,
+      hjust = 1.1, vjust = 1.1, size = 2.8, lineheight = 0.9,
+      fill = "white", alpha = 0.85,
+      family = "sans"
     )
   }
 
   # base-R moving window slope (no extra packages)
-  window_slope <- function(x, y, k = 150, step = 10) {
-    ok <- is.finite(x) & is.finite(y)
+  window_slope <- function(x, y, k = 150, step = 10, min_x = 5) {
+    ok <- is.finite(x) & is.finite(y) & x >= min_x  # Filter low Built%
     x <- x[ok]; y <- y[ok]
     o <- order(x); x <- x[o]; y <- y[o]
     n <- length(x)
@@ -1437,16 +1443,17 @@ analyze_and_visualize_uhi <- function(
 
   label_built <- quick_stats_label(df$Built_Pct, df$LST_mean)
 
-  p1 <- ggplot2::ggplot(df, ggplot2::aes(Built_Pct, LST_mean)) +
+  scatter_lst_built <- ggplot2::ggplot(df, ggplot2::aes(Built_Pct, LST_mean)) +
     ggplot2::geom_bin2d(bins = 35) +
     ggplot2::scale_fill_gradientn(
       colours = c("#EFF3FF","#BDD7E7","#6BAED6","#3182BD","#08519C"),
-      name = "Hex count"
+      name = "Count"
     ) +
     ggplot2::geom_smooth(method = "lm", linewidth = 0.7, colour = "#bd0026", se = TRUE) +
     ggplot2::labs(title = "LST vs Built-up Intensity", x = "Built (%)", y = "LST (deg C)") +
-    annot_top(label_built) +
-    ggplot2::theme_minimal()
+    annot_stats(label_built) +
+    ggplot2::theme_minimal() +
+    ggplot2::theme(legend.position = "bottom", legend.key.width = ggplot2::unit(1, "cm"))
 
   # ============================
   # 2) HEXBIN - LST vs GREEN
@@ -1454,16 +1461,17 @@ analyze_and_visualize_uhi <- function(
 
   label_green <- quick_stats_label(df$Green_Pct, df$LST_mean)
 
-  p2 <- ggplot2::ggplot(df, ggplot2::aes(Green_Pct, LST_mean)) +
+  scatter_lst_green <- ggplot2::ggplot(df, ggplot2::aes(Green_Pct, LST_mean)) +
     ggplot2::geom_bin2d(bins = 35) +
     ggplot2::scale_fill_gradientn(
       colours = c("#f7fcf5","#c7e9c0","#74c476","#31a354","#006d2c"),
-      name = "Hex count"
+      name = "Count"
     ) +
     ggplot2::geom_smooth(method = "lm", linewidth = 0.7, colour = "#006d2c", se = TRUE) +
     ggplot2::labs(title = "LST vs Green Coverage", x = "Green (%)", y = "LST (deg C)") +
-    annot_top(label_green) +
-    ggplot2::theme_minimal()
+    annot_stats(label_green) +
+    ggplot2::theme_minimal() +
+    ggplot2::theme(legend.position = "bottom", legend.key.width = ggplot2::unit(1, "cm"))
 
   # ============================
   # 3) PARTIAL EFFECT - residuals of LST ~ GREEN vs BUILT
@@ -1473,7 +1481,7 @@ analyze_and_visualize_uhi <- function(
   df$resid_g <- stats::residuals(m)
   label_partial <- quick_stats_label(df$Built_Pct, df$resid_g)
 
-  p3 <- ggplot2::ggplot(df, ggplot2::aes(Built_Pct, resid_g)) +
+  scatter_partial <- ggplot2::ggplot(df, ggplot2::aes(Built_Pct, resid_g)) +
     ggplot2::geom_point(alpha = 0.25, size = 0.7, colour = "#888888") +
     ggplot2::geom_smooth(method = "lm", linewidth = 0.7, colour = "#bd0026", se = TRUE) +
     ggplot2::labs(
@@ -1481,30 +1489,54 @@ analyze_and_visualize_uhi <- function(
       subtitle = "Residuals of LST ~ Green, regressed on Built",
       x = "Built (%)", y = "Residual LST (deg C)"
     ) +
-    annot_top(label_partial) +
+    annot_stats(label_partial) +
     ggplot2::theme_minimal()
 
   # ============================
   # 4) MOVING-WINDOW SLOPE - DeltaLST/DeltaBuilt
   # ============================
 
-  ws <- window_slope(df$Built_Pct, df$LST_mean, k = 150, step = 10)
+  ws <- window_slope(df$Built_Pct, df$LST_mean, k = 150, step = 10, min_x = 5)
 
-  p4 <- ggplot2::ggplot(ws, ggplot2::aes(x_mid, slope)) +
+  # Filter extreme slope values for better visualization
+  if (nrow(ws) > 0) {
+    slope_iqr <- stats::IQR(ws$slope, na.rm = TRUE)
+    slope_med <- stats::median(ws$slope, na.rm = TRUE)
+    slope_upper <- slope_med + 3 * slope_iqr
+    slope_lower <- slope_med - 3 * slope_iqr
+    ws$slope_clipped <- pmax(pmin(ws$slope, slope_upper), slope_lower)
+  } else {
+    ws$slope_clipped <- numeric(0)
+  }
+
+  scatter_slope <- ggplot2::ggplot(ws, ggplot2::aes(x_mid, slope_clipped)) +
     ggplot2::geom_line(linewidth = 0.7, colour = "#cb181d") +
     ggplot2::geom_hline(yintercept = 0, colour = "grey60", linetype = "dashed") +
-    ggplot2::labs(title = "Slope Landscape", subtitle = "Rolling regression slope (DeltaLST / DeltaBuilt)",
-                  x = "Built (%)", y = "Local slope") +
+    ggplot2::labs(
+      title = "Slope Landscape",
+      subtitle = "Rolling regression slope (dLST/dBuilt), filtered for stability",
+      x = "Built (%)", y = "Local slope (deg C per %)"
+    ) +
     ggplot2::theme_minimal()
 
   # ============================
   # Assemble dashboard
   # ============================
 
-  scatter_dashboard <- patchwork::wrap_plots(p1, p2, p3, p4, ncol = 2)
+  scatter_dashboard <- patchwork::wrap_plots(
+    scatter_lst_built, scatter_lst_green,
+    scatter_partial, scatter_slope,
+    ncol = 2
+  )
 
-  # keep your original object name to avoid changing returns
-  scatter_plots <- scatter_dashboard
+  # Keep individual plots accessible
+  scatter_plots <- list(
+    dashboard = scatter_dashboard,
+    lst_vs_built = scatter_lst_built,
+    lst_vs_green = scatter_lst_green,
+    partial_effect = scatter_partial,
+    slope_landscape = scatter_slope
+  )
 
 
   message(sprintf("   [OK] Visualizations complete [%.1fs]",
